16.61. cdist-type__hwclock(7) — cdist 6.9.4 documentation

# 16.61. cdist-type__hwclock(7)

## 16.61.1. NAME

cdist-type__hwclock - Manage the hardware real time clock.

## 16.61.2. DESCRIPTION

This type can be used to control how the hardware clock is used by the operating system.

## 16.61.3. REQUIRED PARAMETERS

mode

  What mode the hardware clock is in.

  Acceptable values:

  localtime

    The hardware clock is set to local time (common for systems also running Windows.)

  UTC

    The hardware clock is set to UTC (common on UNIX systems.)

## 16.61.4. OPTIONAL PARAMETERS

None.

## 16.61.5. BOOLEAN PARAMETERS

None.

## 16.61.6. EXAMPLES

    # Make the operating system treat the time read from the hwclock as UTC.
    __hwclock --mode UTC

## 16.61.7. SEE ALSO

hwclock(8)

## 16.61.8. AUTHORS

Dennis Camera <dennis.camera@ssrq-sds-fds.ch>

## 16.61.9. COPYING

Copyright (C) 2020 Dennis Camera. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.